//   #####################################################################
//   ##                                                                 ##
//   ##            The Smart Marketing Javascript Toolkit               ##
//   ##             (C) 1999 Sean McManus. Updated 2019.                ##
//   ##   for help or more information visit https://www.sean.co.uk     ##
//   ##                                                                 ##
//   ##     You may use these routines in your own website provided     ##
//   ##    that this message is not altered or removed. This toolkit    ##
//   ##      is subject to the GNU Library General Public Licence       ##
//   ##           see http://www.fsf.org/copyleft/lgpl.html             ##
//   ##                                                                 ##
//   #####################################################################

function getBannersInfo() {
  // Either return the previously set bannersInfo, or return the default
  return peek_cookie("bannersInfo") || [
    {
      graphic: "moodanim.gif",
      url: "http://www.wildmoodswings.co.uk",
      views: 0
    },
    {
      graphic: "hungersitebanner.jpg",
      url: "http://www.thehungersite.com",
      views: 0
    },
    {
      graphic: "varad.gif",
      url: "https://www.sean.co.uk/a/musicjournalism/var/index.shtm",
      views: 0
    },
    {
      graphic: "rainforestbanner.gif",
      url: "http://www.therainforestsite.com",
      views: 0
    },
    {
      graphic: "care2bigcatsbanner.gif",
      url: "http://bigcats.care2.com",
      views: 0
    }
  ];
}

function setBannersInfo(bannersInfo) {
  return poke_cookie("bannersInfo", bannersInfo);
}

function getInterest() {
  return peek_cookie("interest") || [];
}

function setInterest(interest) {
  return poke_cookie("interest", interest);
}

// Misnomer; this clears the localStorage
function delete_banner_cookie() {
  return localStorage.clear();
}

function poke_cookie(name, value) {
  return localStorage.setItem(name, JSON.stringify(value));
}

function peek_cookie(name) {
  return JSON.parse(localStorage.getItem(name));
}

function reset_banner_views() {
  var banners = getBannersInfo();
  var resetBanners = banners.map(function (banner) {
    banner.views = 0;
    return banner;
  });
  setBannersInfo(resetBanners);
}

// Outputs banner html
function output_banner(i) {
  var banners = getBannersInfo();
  var banner = banners[i];
  banner.views++;
  setBannersInfo(banners);
  return "<a href=\"" + banner.url + "\"><img src=\"" + banner.graphic + "\" border=0></a>";
}

function interest_enquire(i) {
  return getInterest()[i] || 0;
}

function interest_increase(i) {
  var interest = getInterest();
  if (interest[i]) {
    interest[i]++;
  } else {
    interest[i] = 1;
  }
  setInterest(interest);
}

function interest_decrease(i) {
  var interest = getInterest();
  if (interest[i] || interest[i] == 0) {
    interest[i]--;
  } else {
    interest[i] = 0;
  }
  setInterest(interest);
}

function most_views() {
  var most = 0;
  var banners = getBannersInfo();
  banners.forEach(function (banner, i) {
    if (banner.views > banners[most].views) {
      most = i;
    }
  });
  return most;
}

function least_views() {
  var least = 0;
  var banners = getBannersInfo();
  banners.forEach(function (banner, i) {
    if (banner.views < banners[least].views) {
      least = i;
    }
  });
  return least;
}

function most_interested() {
  var most = 0;
  var interest = getInterest();
  interest.forEach(function (value, i) {
    if (value > interest[most]) {
      most = i;
    }
  });
  return most;
}

function least_interested() {
  var least = 0;
  var interest = getInterest();
  interest.forEach(function (value, i) {
    if (value < interest[least]) {
      least = i;
    }
  });
  return least;
}

function countdown(launch_year, launch_month, launch_date, countdown_message, launch_message) {
    var launch_date = new Date(launch_year, launch_month - 1, launch_date); // subtract 1 from launch month because month is an index starting at 0
	var today = new Date().getTime();
	var offset = launch_date - today;
		// offset is in milliseconds, so need to convert x1000 to seconds; x60 to minutes, x60 to hours, x24 to days. = 86,400,000
		days_left = Math.ceil(offset / 86400000)

		if (days_left > 0) 
		    {
                document.write(days_left, " day");
                if (days_left > 1) {
                    document.write("s");
                }		
			document.write(" " + countdown_message);
	        }
		else { document.write(launch_message); }
		
}

function countdown_recurring(launch_month, launch_date, countdown_message, day_message) {

	if ((launch_month - 1 > the_month() ) || (launch_date >= the_date() && launch_month - 1 == the_month() )) {
		launch_year = the_year();	
	}
	else {
				launch_year = the_year();
				launch_year += 1;	
	}

    var launch_date = new Date(launch_year, launch_month - 1, launch_date); // subtract 1 from launch month because month is an index starting at 0	
	var today = new Date().getTime();	
		
	var offset = launch_date - today;
	// offset is in milliseconds, so need to convert x1000 to seconds; x60 to minutes, x60 to hours, x24 to days. = 86,400,000
	days_left = Math.ceil(offset / 86400000)	

		if (days_left > 0) 
		    {
                document.write(days_left, " day");
                if (days_left > 1) {
                    document.write("s");
                }		
			document.write(" " + countdown_message);
	        }
		else { document.write(day_message); }	
}




function month_name(temp) {
  months = ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"];
  return months[temp];
}

function day_name(temp) {
  daynames = ["Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"];
  return daynames[temp];
}

function the_date() {
  today = new Date();
  temp = today.getDate();
  return temp;
}

function the_month() {
  today = new Date();
  temp = today.getMonth();
  return temp;
}

function the_year() {
  today = new Date();
  temp = today.getFullYear();
  return temp;
}

function the_day() {
  today = new Date();
  temp = today.getDay();
  return temp;
}

function paddingzero(number) {
  if (number > 9) {
    return number;
  } else return "0" + number;
}

function the_hour() {
  today = new Date();
  temp = today.getHours();
  return temp;
}

function the_minute() {
  today = new Date();
  temp = today.getMinutes();
  temp = paddingzero(temp);
  return temp;
}

function the_second() {
  today = new Date();
  temp = today.getSeconds();
  temp = paddingzero(temp);
  return temp;
}

function print(incoming) {
  document.write(incoming);
}

// The Smart Marketing Javascript Toolkit - (C) 1999 Sean McManus - www.sean.co.uk
